@@ -42,11 +42,11 @@ class HomeAssistantCog(commands.Cog):
         await context.response.send_message(f"Testing is {choices}ing")
 
     @app_commands.command(name="tesla")
-    @app_commands.choices(choices=get_functions(ha.Alarm))
+    @app_commands.choices(choices=get_functions(ha.Lock))
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        testing = ha.Lock("taylor_swiftly_doors")
+        testing = ha.Lock(entity_id="taylor_swiftly_doors", location="home")
         testing_function = getattr(testing, choices)
         testing_function()
         await context.response.send_message(f"Testing is {choices}ing")
